/**
 * @file
 * VuoList_VuoLayer C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoLayer_H
#define VuoList_VuoLayer_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoLayer VuoList_VuoLayer
 * A list of @ref VuoLayer elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoLayer
 * A list of @ref VuoLayer elements.
 */
#ifndef VuoList_VuoLayer_TYPE_DEFINED
typedef void * VuoList_VuoLayer;
#endif

/**
 * Creates a new list of @ref VuoLayer elements.
 */
VuoList_VuoLayer VuoListCreate_VuoLayer(void);

/**
 * Returns the @ref VuoLayer at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoLayer VuoListGetValueAtIndex_VuoLayer(const VuoList_VuoLayer list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoLayer(VuoList_VuoLayer list, const VuoLayer value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoLayer(VuoList_VuoLayer list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoLayer(VuoList_VuoLayer list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoLayer(const VuoList_VuoLayer list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoLayer VuoList_VuoLayer_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoLayer_jsonFromValue(const VuoList_VuoLayer value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoLayer_summaryFromValue(const VuoList_VuoLayer value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoLayer VuoList_VuoLayer_valueFromString(const char *str);
char * VuoList_VuoLayer_stringFromValue(const VuoList_VuoLayer value);
/// @}

/**
 * @}
 */

#endif
