/**
 * @file
 * VuoList_VuoLeapFrame C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoLeapFrame_H
#define VuoList_VuoLeapFrame_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoLeapFrame VuoList_VuoLeapFrame
 * A list of @ref VuoLeapFrame elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoLeapFrame
 * A list of @ref VuoLeapFrame elements.
 */
#ifndef VuoList_VuoLeapFrame_TYPE_DEFINED
typedef void * VuoList_VuoLeapFrame;
#endif

/**
 * Creates a new list of @ref VuoLeapFrame elements.
 */
VuoList_VuoLeapFrame VuoListCreate_VuoLeapFrame(void);

/**
 * Returns the @ref VuoLeapFrame at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoLeapFrame VuoListGetValueAtIndex_VuoLeapFrame(const VuoList_VuoLeapFrame list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoLeapFrame(VuoList_VuoLeapFrame list, const VuoLeapFrame value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoLeapFrame(VuoList_VuoLeapFrame list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoLeapFrame(VuoList_VuoLeapFrame list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoLeapFrame(const VuoList_VuoLeapFrame list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoLeapFrame VuoList_VuoLeapFrame_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoLeapFrame_jsonFromValue(const VuoList_VuoLeapFrame value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoLeapFrame_summaryFromValue(const VuoList_VuoLeapFrame value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoLeapFrame VuoList_VuoLeapFrame_valueFromString(const char *str);
char * VuoList_VuoLeapFrame_stringFromValue(const VuoList_VuoLeapFrame value);
/// @}

/**
 * @}
 */

#endif
